==> apache-jena_4.5.0.orig.tar.gz: jena-jena-4.5.0/jena-permissions/src/test/java/org/apache/jena/permissions/contract/graph/SecuredGraphContractTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jena.permissions.contract.graph;

import org.apache.jena.graph.Factory;
import org.apache.jena.graph.Graph;
import org.apache.jena.graph.test.MetaTestGraph;
import org.apache.jena.permissions.MockSecurityEvaluator;
import org.apache.jena.permissions.SecurityEvaluator;

public class SecuredGraphContractTests extends MetaTestGraph {

    private final SecurityEvaluator eval;

    public SecuredGraphContractTests(final Class<? extends Graph> graphClass, final String name) {
        super(graphClass, name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    public SecuredGraphContractTests(final String name) {
        super(name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    @Override
    public Graph getGraph() {
        return org.apache.jena.permissions.Factory.getInstance(eval, getName(), Factory.createDefaultGraph());
    }

}

==> apache-jena_4.9.0.orig.tar.gz: jena-jena-4.9.0/jena-permissions/src/test/java/org/apache/jena/permissions/contract/graph/SecuredGraphContractTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jena.permissions.contract.graph;

import org.apache.jena.graph.Graph;
import org.apache.jena.graph.GraphMemFactory;
import org.apache.jena.graph.test.MetaTestGraph;
import org.apache.jena.permissions.MockSecurityEvaluator;
import org.apache.jena.permissions.SecurityEvaluator;

public class SecuredGraphContractTests extends MetaTestGraph {

    private final SecurityEvaluator eval;

    public SecuredGraphContractTests(final Class<? extends Graph> graphClass, final String name) {
        super(graphClass, name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    public SecuredGraphContractTests(final String name) {
        super(name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    @Override
    public Graph getGraph() {
        return org.apache.jena.permissions.Factory.getInstance(eval, getName(), GraphMemFactory.createDefaultGraph());
    }

}
